@@ -1,7 +1,6 @@
 import os
 
 import mlflow
-import pytest
 import yaml
 from kedro.framework.session import KedroSession
 from kedro.framework.startup import bootstrap_project
@@ -9,25 +8,17 @@ from mlflow.tracking import MlflowClient
 
 from kedro_mlflow.config.kedro_mlflow_config import (
     KedroMlflowConfig,
-    KedroMlflowConfigError,
+    _validate_mlflow_tracking_uri,
 )
 
 
-def test_kedro_mlflow_config_init_wrong_path(tmp_path):
-    # create a ".kedro.yml" file to identify "tmp_path" as the root of a kedro project
-    with pytest.raises(
-        KedroMlflowConfigError, match="is not the root of kedro project"
-    ):
-        KedroMlflowConfig(project_path=tmp_path)
-
-
-def test_kedro_mlflow_config_init(kedro_project_with_mlflow_conf):
+def test_kedro_mlflow_config_init():
     # kedro_project_with_mlflow_conf is a global fixture in conftest
 
-    config = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
-    assert config.dict(exclude={"project_path"}) == dict(
+    config = KedroMlflowConfig()
+    assert config.dict() == dict(
         server=dict(
-            mlflow_tracking_uri=(kedro_project_with_mlflow_conf / "mlruns").as_uri(),
+            mlflow_tracking_uri=None,  # not setup, not modified yet
             credentials=None,
         ),
         tracking=dict(
@@ -52,7 +43,6 @@ def test_kedro_mlflow_config_new_experiment_does_not_exists(
 ):
 
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(mlflow_tracking_uri="mlruns"),
         tracking=dict(experiment=dict(name="exp1")),
     )
@@ -92,7 +82,6 @@ def test_kedro_mlflow_config_experiment_exists(kedro_project_with_mlflow_conf):
     ).as_uri()
     MlflowClient(mlflow_tracking_uri).create_experiment("exp1")
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(mlflow_tracking_uri="mlruns"),
         tracking=dict(experiment=dict(name="exp1")),
     )
@@ -119,7 +108,6 @@ def test_kedro_mlflow_config_experiment_was_deleted(kedro_project_with_mlflow_co
 
     # the config must restore properly the experiment
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(mlflow_tracking_uri="mlruns"),
         tracking=dict(experiment=dict(name="exp1")),
     )
@@ -142,7 +130,6 @@ def test_kedro_mlflow_config_setup_set_experiment_globally(
 
     # the config must restore properly the experiment
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(mlflow_tracking_uri="mlruns"),
         tracking=dict(experiment=dict(name="incredible_exp")),
     )
@@ -177,7 +164,6 @@ def test_kedro_mlflow_config_setup_set_tracking_uri(kedro_project_with_mlflow_co
     mlflow_tracking_uri = (kedro_project_with_mlflow_conf / "awesome_tracking").as_uri()
 
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(mlflow_tracking_uri="awesome_tracking"),
         tracking=dict(experiment=dict(name="exp1")),
     )
@@ -198,7 +184,6 @@ def test_kedro_mlflow_config_setup_export_credentials(kedro_project_with_mlflow_
 
     # the config must restore properly the experiment
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(credentials="my_mlflow_creds"),
     )
 
@@ -221,7 +206,6 @@ def test_kedro_mlflow_config_setup_tracking_priority(kedro_project_with_mlflow_c
     )
 
     config = KedroMlflowConfig(
-        project_path=kedro_project_with_mlflow_conf,
         server=dict(
             mlflow_tracking_uri="mlruns1",
             credentials="my_mlflow_creds",
@@ -242,30 +226,40 @@ def test_kedro_mlflow_config_setup_tracking_priority(kedro_project_with_mlflow_c
     (kedro_project_with_mlflow_conf / "conf/base/credentials.yml").write_text("")
 
 
-@pytest.mark.parametrize(
-    "uri",
-    [
-        (r"mlruns"),  # relative
-        (pytest.lazy_fixture("tmp_path")),  # absolute
-        (r"file:///C:/fake/path/mlruns"),  # local uri
-    ],
-)
-def test_kedro_mlflow_config_validate_uri_local(kedro_project_with_mlflow_conf, uri):
+def test_validate_uri_local_relative_path(kedro_project_with_mlflow_conf):
 
-    kmc = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
-    assert kmc._validate_uri(uri=uri).startswith(r"file:///")  # relative
+    validated_uri = _validate_mlflow_tracking_uri(
+        uri=r"mlruns", project_path=kedro_project_with_mlflow_conf
+    )
+    assert validated_uri == (kedro_project_with_mlflow_conf / "mlruns").as_uri()
+
+
+def test_validate_uri_local_absolute_posix(kedro_project_with_mlflow_conf, tmp_path):
+
+    validated_uri = _validate_mlflow_tracking_uri(
+        uri=tmp_path.as_posix(), project_path=kedro_project_with_mlflow_conf
+    )
+    assert validated_uri == tmp_path.as_uri()
+
+
+def test_validate_uri_local_absolute_uri(kedro_project_with_mlflow_conf, tmp_path):
+
+    validated_uri = _validate_mlflow_tracking_uri(
+        uri=tmp_path.as_uri(), project_path=kedro_project_with_mlflow_conf
+    )
+    assert validated_uri == tmp_path.as_uri()
 
 
 def test_kedro_mlflow_config_validate_uri_databricks(kedro_project_with_mlflow_conf):
     # databricks is a reseved keyword which should not be modified
-    kmc = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
-    config_uri = kmc._validate_uri(uri="databricks")
-
+    config_uri = _validate_mlflow_tracking_uri(
+        uri="databricks", project_path=kedro_project_with_mlflow_conf
+    )
     assert config_uri == "databricks"
 
 
 def test_from_dict_to_dict_idempotent(kedro_project_with_mlflow_conf):
-    config = KedroMlflowConfig(project_path=kedro_project_with_mlflow_conf)
+    config = KedroMlflowConfig()
     original_config_dict = config.dict()
     # modify config
     reloaded_config = KedroMlflowConfig.parse_obj(original_config_dict)
